@@ -4,8 +4,10 @@ from .plot import (create_pie,
                    create_treemap,
                    create_violin,
                    create_sunburst,
-                   create_correlation_plot,create_density_chart,
-                   create_histogram)
+                   create_correlation_plot,
+                   create_density_chart,
+                   create_histogram,
+                   create_bar)
 from .utils import (columns_with_distinct_values,
                     extract_col_types,
                     figures_to_html)
@@ -40,6 +42,7 @@ class AutoPlot(object):
                  include_violin=True,
                  include_density_heatmap=True,
                  include_density_contour=True,
+                 include_bar=False,
                  violinmode='group',
                  violin_box=True,
                  violin_points='all',
@@ -49,13 +52,18 @@ class AutoPlot(object):
                  maximum_number_sectors=3,
                  maximum_number_boxplots=5,
                  maximum_number_violinplots=5,
+                 maximum_number_bars=10,
                  density_max_color_groups=2,
                  pie_chart_hole=False,
                  create_html=True,
                  orientation='v',
                  opacity=1.0,
                  color=None,
-                 color_hierachical_charts=None
+                 color_hierachical_charts=None,
+                 width=None,
+                 height=None,
+                 barmode='relative',
+                 barnorm=None
                  ):
         """
         Entry point for automated data visualization
@@ -63,7 +71,7 @@ class AutoPlot(object):
         :param nbins:int, number of bins on x axis
         :param nbinsy:int, number of bins on y axis
         :param marginals:str, marginal must be one of 'rug','box','violin','histogram
-        :param cumulative:
+        :param cumulative:bool, for histograms whether to cumulate the output
         :param filename:str, filename for the html file
         :param box_points:str, whether to show the points in a box plot possible options are 'outliers', 'all',False,
                  'suspectedoutliers'
@@ -95,12 +103,13 @@ class AutoPlot(object):
         :param correlation_method: str, method to use to compute correlation
         :param maximum_number_sectors: int, maximum number of sectors in pie charts
         :param maximum_number_boxplots:int, maximum_number_boxplots
+        :param maximum_number_bars:int, maximum number of bars
         :param density_max_color_groups:int, maximum number of color points in density chart
         :param pie_chart_hole: boolean, whether to include a hole in pie chart or not
         :param create_html:boolean, whether to create an html file or not
         :param orientation: str, orientation of the figure, 'v' or 'h'
         :param opacity:float, opacity set for the markers, value between 0 and 1
-        :param color: str, color option for boxplots
+        :param color: str, color option for boxplots, histogram
         :param color_hierachical_charts: str, color option for treemaps and sunburst charts
 
         Usage
@@ -146,6 +155,7 @@ class AutoPlot(object):
         self.include_violin = include_violin
         self.include_density_contour = include_density_contour
         self.include_density_heatmap = include_density_heatmap
+        self.include_bar = include_bar
         self.violinmode = violinmode
         self.violin_box = violin_box
         self.violin_points = violin_points
@@ -155,12 +165,17 @@ class AutoPlot(object):
         self.maximum_number_sectors = maximum_number_sectors
         self.maximum_number_boxplots = maximum_number_boxplots
         self.maximum_number_violinplots = maximum_number_violinplots
+        self.maximum_number_bars = maximum_number_bars
         self.density_max_color_groups = density_max_color_groups
         self.create_html = create_html
         self.pie_chart_hole = pie_chart_hole
         self.color_hierachical_charts = color_hierachical_charts
         self.pie_sectors = columns_with_distinct_values(df=self.df, categorical_only=True,
                                                         maximum_number_distinct_values=self.maximum_number_sectors)
+        self.width = width
+        self.height = height
+        self.barmode = barmode
+        self.barnorm = barnorm
         assert isinstance(df, pd.DataFrame), "df must be a pandas dataframe"
         assert isinstance(nbins, int) or nbins is None, "nbins must be an integer or None"
         assert isinstance(nbinsy, int) or nbinsy is None, "nbinsy must be an integer or None"
@@ -191,6 +206,7 @@ class AutoPlot(object):
         assert isinstance(include_violin, bool)
         assert isinstance(include_density_contour,bool)
         assert isinstance(include_density_heatmap,bool)
+        assert isinstance(include_bar, bool)
         assert violinmode in ['group', 'overlay'], "violinmode must be either group or overlay"
         assert isinstance(violin_box, bool)
         assert violin_points in ['all', 'outliers', 'suspectedoutliers', False]
@@ -215,6 +231,10 @@ class AutoPlot(object):
         obj_cols = col_types['object']
         assert (color in cat_cols) or (color in bool_cols) or (color in obj_cols) or color is None
         assert color_hierachical_charts in self.column_types['numeric'] or color_hierachical_charts is None, "color_hierachical_charts must be the name of a numeric column or None"
+        assert isinstance(width, int) or width is None
+        assert isinstance(height, int) or height is None
+        assert barmode in ['group', 'overlay', 'relative']
+        assert barnorm in [None, 'fraction', 'percent']
 
     def chart_type(self):
         """
@@ -256,6 +276,7 @@ class AutoPlot(object):
         if len(categorical_cols) >0 or len(boolean_cols) > 0 or len(object_cols) > 0:
             chart_types.append('treemaps')
             chart_types.append('sunburst')
+            chart_types.append('bar')
         if len(datetime_cols) !=0 or len(timedelta_cols) != 0:
             chart_types.append('timeseries_plot')
         if len(self.pie_sectors) !=0:
@@ -284,12 +305,31 @@ class AutoPlot(object):
 
         if len(chart_types) != 0:
             for chart in chart_types:
+                if chart == 'bar' and self.include_bar:
+                    bar_list = create_bar(df=self.df,
+                                          col_types=self.column_types,
+                                          maximum_number_bars=self.maximum_number_bars,
+                                          color=self.color,
+                                          orientation=self.orientation,
+                                          opacity=self.opacity,
+                                          barmode=self.barmode,
+                                          filename='bars',
+                                          width=self.width,
+                                          height=self.height,
+                                          log_y=False,
+                                          log_x=False,
+                                          create_html=False
+                                          )
+
+                    figure_list.extend(bar_list)
                 if chart == 'pie' and self.include_pie:
 
                     pie_list = create_pie(df=self.df,
                                           numeric_cols=numeric_cols,
                                           list_of_categorical_columns=self.pie_sectors,
                                           opacity=self.opacity,
+                                          width=self.width,
+                                          height=self.height,
                                           create_html=False,
                                           hole=self.pie_chart_hole,
                                           filename='pie')
@@ -303,7 +343,7 @@ class AutoPlot(object):
                                                        marginal_y=self.marginal_x,
                                                        marginal_x=self.marginal_y,
                                                        orientation=self.orientation,
-                                                       opacity=self.opacity,
+                                                       opacity=self.opacity,width=self.width,height=self.height,
                                                        maximum_color_groups=self.scatter_maximum_color_groups,
                                                        log_x=self.log_x,
                                                        log_y=self.log_y,
@@ -314,6 +354,8 @@ class AutoPlot(object):
                 if chart == 'correlation_plot' and self.include_correlation:
                     correlation_plot_list = create_correlation_plot(df=self.df,
                                                                     create_html=False,
+                                                                    width=self.width,
+                                                                    height=self.height,
                                                                     correlation_method=self.correlation_method)
                     figure_list.extend(correlation_plot_list)
 
@@ -321,11 +363,17 @@ class AutoPlot(object):
                     histogram_list = create_histogram(df=self.df,
                                                       numeric_cols=numeric_cols,
                                                       nbins=self.nbins,
+                                                      color=self.color,
+                                                      width=self.width,
+                                                      height=self.height,
                                                       marginal=self.marginal_x,
                                                       cumulative=self.cumulative,
                                                       histfunc=self.histfunc,
                                                       histnorm=self.histnorm,
                                                       filename='histogram',
+                                                      barmode=self.barmode,
+                                                      barnorm=self.barnorm,
+                                                      opacity=self.opacity,
                                                       create_html=False,
                                                       orientation=self.orientation)
 
@@ -336,8 +384,11 @@ class AutoPlot(object):
                                           maximum_number_boxplots=self.maximum_number_boxplots,
                                           col_types= self.column_types,
                                           points=self.points,
+                                          width=self.width,
+                                          height=self.height,
                                           boxmode=self.boxmode,
                                           notched=self.notched,
+                                          orientation=self.orientation,
                                           color=self.color,
                                           filename='box',
                                           create_html=False)
@@ -348,6 +399,8 @@ class AutoPlot(object):
                     treemap_list = create_treemap(df=self.df,
                                                   col_types=self.column_types,
                                                   create_html=False,
+                                                  width=self.width,
+                                                  height=self.height,
                                                   color=self.color_hierachical_charts,
                                                   filename='treemap',
                                                   limit=self.treemap_path_limit)
@@ -357,6 +410,8 @@ class AutoPlot(object):
                     sunburst_list = create_sunburst(df=self.df,
                                                     col_types=self.column_types,
                                                     create_html=False,
+                                                    width=self.width,
+                                                    height=self.height,
                                                     color=self.color_hierachical_charts,
                                                     filename='sunburst',
                                                     limit=self.sunburst_path_limit)
@@ -368,6 +423,9 @@ class AutoPlot(object):
                                                 col_types= self.column_types,
                                                 maximum_number_violinplots=self.maximum_number_violinplots,
                                                 filename='violin',
+                                                width=self.width,
+                                                height=self.height,
+                                                orientation=self.orientation,
                                                 create_html=False,
                                                 points=self.violin_points,
                                                 display_box=self.violin_box,
@@ -380,6 +438,8 @@ class AutoPlot(object):
                                                                 col_types=self.column_types,
                                                                 nbinsx=self.nbins,
                                                                 nbinsy=self.nbinsy,
+                                                                width=self.width,
+                                                                height=self.height,
                                                                 maximum_color_groups=self.density_max_color_groups,
                                                                 typr_of_chart='contour',
                                                                 orientation=self.orientation,
@@ -398,6 +458,8 @@ class AutoPlot(object):
                                                                 col_types=self.column_types,
                                                                 nbinsx=self.nbins,
                                                                 nbinsy=self.nbinsy,
+                                                                width=self.width,
+                                                                height=self.height,
                                                                 maximum_color_groups=self.density_max_color_groups,
                                                                 typr_of_chart='heatmap',
                                                                 orientation=self.orientation,
