@@ -13,6 +13,8 @@ def create_pie(df,
                numeric_cols,
                list_of_categorical_columns,
                create_html=False,
+               width=None,
+               height=None,
                opacity=1.0,
                hole=False,
                filename='pie'):
@@ -25,6 +27,8 @@ def create_pie(df,
                                                         maximum_number_distinct_values=maximum_number_sectors)
             Also output of extract_categorical_cols in tabular/utils module
     :param create_html:boolean, whether the figures should be converted to HTML or not
+    :param width: int, width of chart in pixels
+    :param height: int, height of chart in pixels
     :param opacity: float, Value between 0 and 1. Sets the opacity for markers
     :param hole:boolean, hole in the pie chart
     :param filename:str, a suitable name for the produced html file, exclude the extension
@@ -42,6 +46,8 @@ def create_pie(df,
     assert isinstance(hole, bool), "hole must be a boolean"
     assert isinstance(filename, str), "filename must be a string without a dot or an extension"
     assert '.' not in filename, "filename doesn't need an extension"
+    assert isinstance(width, int) or width is None
+    assert isinstance(height, int) or height is None
 
     figure_list = list()
 
@@ -52,7 +58,7 @@ def create_pie(df,
             for name in list_of_categorical_columns:
                 plot = px.pie(names=name,
                               data_frame=df,
-                              values=value,
+                              values=value,width=width, height=height,
                               hole=hole,
                               title='Pie chart showing distribution of {} across {} segments'.format(value, name))
 
@@ -67,10 +73,13 @@ def create_pie(df,
 def create_violin(df,
                   col_types,
                   filename='violin',
+                  width=None,
+                  height=None,
                   create_html=True,
                   violinmode='group',
                   points='all',
                   display_box=True,
+                  orientation='v',
                   color=None,
                   maximum_number_violinplots=7
                   ):
@@ -80,10 +89,13 @@ def create_violin(df,
     :param col_types: dictionary that contains mapping of column type to list of column names
                     It is the output of extract_col_types in tabular module
     :param filename: str, filename for the html file
+    :param width: int, width of chart in pixels
+    :param height: int, height of chart in pixels
     :param create_html: boolean, whether to create an html file or not
     :param violinmode: str, how you want the charts to be displayed
     :param points: str, how the points in the violin chart should be displayed
     :param display_box: boolean, whether to display a box within the violin chart
+    :param orientation: str, the orientation of the figure, 'v' or 'h'
     :param color:
     :param maximum_number_violinplots:
     :return:list which contains plotly graph objects
@@ -108,6 +120,9 @@ def create_violin(df,
     assert points in ['all', 'outliers', 'suspectedoutliers', False],"accepted values for points 'all', 'outliers', " \
                                                                      "'suspectedoutliers'"
     assert '.' not in filename, "filename doesn't need an extension"
+    assert isinstance(width, int) or width is None
+    assert isinstance(height, int) or height is None
+    assert orientation in ['v', 'h'], "orientation must be a string with either v or h"
 
     figure_list = list()
 
@@ -122,10 +137,11 @@ def create_violin(df,
 
                 plot = px.violin(data_frame=df,
                                  x=category,
-                                 y=col,
+                                 y=col,width=width, height=height,
                                  points=points,
                                  violinmode=violinmode,
                                  box=display_box,
+                                 orientation=orientation,
                                  color=color,
                                  title='Violinplot showing distribution of {} across {} categories'.format(col,category))
                 figure_list.append(plot)
@@ -140,6 +156,8 @@ def create_box(df,
                col_types,
                points='outliers',
                boxmode='group',
+               width=None,
+               height=None,
                notched=False,
                color=None,
                filename='box',
@@ -158,6 +176,8 @@ def create_box(df,
                     Options are 'group' or 'overlay'. In group mode,
                     boxes are placed beside each other, in overlay mode,
                     boxes are placed on top of each other.
+    :param width: int, width of chart in pixels
+    :param height: int, height of chart in pixels
     :param notched: boolean, True or False, boxes are drawn with notches
     :param color:
     :param filename::str, filename for the html file
@@ -189,6 +209,8 @@ def create_box(df,
     assert '.' not in filename, "filename doesn't need an extension"
     assert isinstance(orientation,str), "orientation must be a string"
     assert orientation in ['v','h'], "options for orientation are 'v' or 'h' "
+    assert isinstance(width, int) or width is None
+    assert isinstance(height, int) or height is None
 
     figure_list = list()
     numeric_cols = col_types['numeric']
@@ -203,7 +225,7 @@ def create_box(df,
 
                 plot = px.box(data_frame=df,
                               x=category,
-                              y=col,
+                              y=col,width=width, height=height,
                               points=points,
                               boxmode=boxmode,
                               notched=notched,
@@ -224,6 +246,8 @@ def create_treemap(df,
                    col_types,
                    create_html=True,
                    color=None,
+                   width=None,
+                   height=None,
                    filename='treemap',
                    limit=2
                    ):
@@ -234,6 +258,8 @@ def create_treemap(df,
                     It is the output of extract_col_types in tabular module
     :param create_html: boolean, whether to create an html file or not
     :param color: str, column name to use for color
+    :param width: int, width of chart in pixels
+    :param height: int, height of chart in pixels
     :param filename::str, filename for the html file
     :param limit:int, maximum path depth
     :return:list which contains plotly graph objects
@@ -252,6 +278,8 @@ def create_treemap(df,
     assert 'datetime' in keys, "col_types dictionary missing key datetime"
     assert 'timedelta' in keys, "col_types dictionary missing key timedelta"
     assert '.' not in filename, "filename doesn't need an extension"
+    assert isinstance(width, int) or width is None
+    assert isinstance(height, int) or height is None
 
     figure_list = list()
 
@@ -265,7 +293,7 @@ def create_treemap(df,
             plot = px.treemap(data_frame=df,
                               path=path_list,
                               color=color,
-                              values=col,
+                              values=col,width=width, height=height,
                               title='Treemap of {} across paths {}'.format(col, str(path_list))
                               )
 
@@ -280,17 +308,21 @@ def create_treemap(df,
 def create_sunburst(df,
                     col_types,
                     color=None,
+                    width=None,
+                    height=None,
                     create_html=True,
                     filename='sunburst',
                     limit=2
                     ):
     """
 
-    :param df:
+    :param df:pandas dataframe
     :param col_types: dictionary that contains mapping of column type to list of column names
                     It is the output of extract_col_types in tabular module
     :param create_html: boolean, whether to create an html file or not
     :param color: str, column name to color the chart
+    :param width: int, width of chart in pixels
+    :param height: int, height of chart in pixels
     :param filename::str, filename for the html file
     :param limit:int, maximum path depth
     :return:list which contains plotly graph objects
@@ -310,6 +342,8 @@ def create_sunburst(df,
     assert 'timedelta' in keys, "col_types dictionary missing key timedelta"
     assert '.' not in filename, "filename doesn't need an extension"
     assert color in col_types['numeric'] or color is None
+    assert isinstance(width, int) or width is None
+    assert isinstance(height, int) or height is None
 
     figure_list = list()
 
@@ -324,6 +358,8 @@ def create_sunburst(df,
                                color=color,
                                path=path_list,
                                values=col,
+                               width=width,
+                               height=height,
                                title='Sunburst chart of {} across paths {}'.format(col, str(path_list))
                                )
 
@@ -338,6 +374,8 @@ def create_sunburst(df,
 def create_correlation_plot(df,
                             correlation_method='pearson',
                             create_html=False,
+                            width=None,
+                            height=None,
                             filename='correlation_plot'):
     """
     Creates a correlation plot for the provided dataframe
@@ -345,6 +383,8 @@ def create_correlation_plot(df,
     :param df: pandas dataframe
     :param correlation_method: str, method for computing correlation, one of kendall, pearson, spearman
     :param create_html: boolean, whether to create html file or not
+    :param width: int, width of chart in pixels
+    :param height: int, height of chart in pixels
     :param filename:str, name of file, the extension is excluded
     :return: list of graph objects
     """
@@ -354,6 +394,8 @@ def create_correlation_plot(df,
     assert isinstance(filename, str), "filename must be a string with a dot or an extension"
     assert '.' not in filename, "filename doesn't need an extension"
     assert correlation_method in ['pearson', 'kendall', 'spearman']
+    assert isinstance(width, int) or width is None
+    assert isinstance(height, int) or height is None
 
     figure_list = list()
 
@@ -361,7 +403,7 @@ def create_correlation_plot(df,
 
         correlation = calculate_correlation(df=df, method=correlation_method)
 
-        plot = px.imshow(img=correlation,
+        plot = px.imshow(img=correlation,width=width, height=height,
                          title='Correlation plot using {} method'.format(correlation_method))
 
         figure_list.append(plot)
@@ -376,12 +418,18 @@ def create_histogram(df,
                      numeric_cols,
                      nbins=20,
                      marginal=None,
+                     width=None,
+                     height=None,
                      cumulative=False,
                      histfunc='sum',
                      histnorm=None,
                      filename='histogram',
                      create_html=True,
-                     orientation='v'
+                     orientation='v',
+                     color=None,
+                     opacity=1.0,
+                     barmode='relative',
+                     barnorm=None
                      ):
     """
 
@@ -389,12 +437,18 @@ def create_histogram(df,
     :param numeric_cols:list of columns with numeric columns
     :param nbins:int, number of bins
     :param marginal:str, marginal must be one of 'rug','box','violin','histogram
+    :param width: int, width of chart in pixels
+    :param height: int, height of chart in pixels
     :param cumulative:bool
     :param histfunc:str, histfunc must be one of 'count', 'sum', 'avg','min','max'
     :param histnorm:str, normalization method for histogram 'percent','probability','density','probability density'
     :param filename: str, name of file, the extension must be excluded
     :param create_html: boolean, whether to create an html file or not
     :param orientation: str, the orientation of the figure, 'v' or 'h'
+    :param color: str, column name to color the chart
+    :param opacity: float Value between 0 and 1. Sets the opacity for markers
+    :param barmode:
+    :param barnorm:
     :return:list which contains plotly graph objects
     """
     assert isinstance(df, pd.DataFrame), "df must be a pandas dataframe"
@@ -405,10 +459,16 @@ def create_histogram(df,
     assert histfunc in ['count', 'sum', 'avg', 'min',
                         'max'], "histfunc must be one of 'count', 'sum', 'avg','min','max' "
     assert histnorm in ['percent', 'probability', 'density', 'probability density', None]
-    assert isinstance(filename, str), "filename must be a string with a dot or an extension"
+    assert isinstance(filename, str), "filename must be a string without a dot or an extension"
     assert '.' not in filename, "filename doesn't need an extension"
     assert isinstance(create_html, bool), "create_html must be a boolean"
     assert orientation in ['v','h']
+    assert isinstance(width, int) or width is None
+    assert isinstance(height, int) or height is None
+    assert isinstance(opacity,float)
+    assert 1.0 >= opacity >= 0.0
+    assert barmode in ['group','overlay','relative']
+    assert barnorm in [None,'fraction','percent']
 
     figure_list = list()
 
@@ -417,12 +477,18 @@ def create_histogram(df,
             plot = px.histogram(data_frame=df,
                                 nbins=nbins,
                                 x=col,
+                                width=width,
+                                height=height,
                                 marginal=marginal,
                                 cumulative=cumulative,
                                 histfunc=histfunc,
                                 histnorm=histnorm,
                                 orientation=orientation,
-                                title='Distribution of {}'.format(col)
+                                title='Distribution of {}'.format(col),
+                                color=color,
+                                opacity=opacity,
+                                barmode=barmode,
+                                barnorm=barnorm
                                 )
             figure_list.append(plot)
 
@@ -436,19 +502,24 @@ def create_scatter(df,
                    col_types,
                    filename='scatter',
                    marginal_x=None,
+                   width=None,
+                   height=None,
                    marginal_y=None,
                    log_x=False,
                    log_y=False,
-                   orientation='v',size=None,
+                   orientation='v',
+                   size=None,
                    opacity=1.0,
                    maximum_color_groups=5,
                    create_html=True):
     """
-    :param df:
+    :param df:pandas dataframe
     :param col_types: dictionary that contains mapping of column type to list of column names
                     It is the output of extract_col_types in tabular module
     :param filename:str, name of file, the extension must be excluded
     :param marginal_x:options for including marginal charts on x axis
+    :param width: int, width of chart in pixels
+    :param height: int, height of chart in pixels
     :param marginal_y:options for including marginal charts on y axis
     :param log_x:boolean, whether to create a log axis
     :param log_y:boolean, whether to create a log axis
@@ -482,6 +553,8 @@ def create_scatter(df,
     assert isinstance(create_html, bool), "create_html must be a boolean"
     assert orientation in ['v', 'h']
     assert isinstance(maximum_color_groups, int)
+    assert isinstance(width, int) or width is None
+    assert isinstance(height, int) or height is None
 
     figure_list = list()
     numeric_cols = col_types['numeric']
@@ -502,7 +575,7 @@ def create_scatter(df,
         for color in columns_with_distinct:
             plot = px.scatter(data_frame=df,
                               x=x,
-                              y=y,
+                              y=y,width=width, height=height,
                               log_y=log_y,
                               log_x=log_x,
                               opacity=opacity,
@@ -524,6 +597,8 @@ def create_density_chart(df,
                          col_types,
                          nbinsx=None,
                          nbinsy=None,
+                         width=None,
+                         height=None,
                          maximum_color_groups=4,
                          typr_of_chart='contour',
                          filename='density_charts',
@@ -543,6 +618,8 @@ def create_density_chart(df,
                     It is the output of extract_col_types in tabular module
     :param nbinsx: int, number of bins on x axis
     :param nbinsy: int, number of bins on y axis
+    :param width: int, width of chart in pixels
+    :param height: int, height of chart in pixels
     :param maximum_color_groups: int, maximum number of color groups in the density charts
     :param typr_of_chart: str, 'contour' or 'heatmap'
     :param filename: str, name of file, the extension must be excluded
@@ -581,6 +658,8 @@ def create_density_chart(df,
     assert isinstance(filename, str), "filename must be a string with a dot or an extension"
     assert '.' not in filename, "filename doesn't need an extension"
     assert typr_of_chart in ['contour','heatmap']
+    assert isinstance(width, int) or width is None
+    assert isinstance(height, int) or height is None
 
     figure_list = list()
     numeric_cols = col_types['numeric']
@@ -608,7 +687,7 @@ def create_density_chart(df,
                     plot = px.density_contour(data_frame=df,
                                               x=x,
                                               y=y,
-                                              z=z,
+                                              z=z,width=width, height=height,
                                               color=color,
                                               histnorm=histnorm,
                                               histfunc=histfunc,
@@ -629,6 +708,8 @@ def create_density_chart(df,
                                           x=x,
                                           y=y,
                                           z=z,
+                                          width=width,
+                                          height=height,
                                           histnorm=histnorm,
                                           histfunc=histfunc,
                                           nbinsx=nbinsx,
@@ -647,6 +728,100 @@ def create_density_chart(df,
     return figure_list
 
 
+def create_bar(df,
+               col_types,
+               maximum_number_bars=10,
+               color=None,
+               orientation='v',
+               opacity=1.0,
+               barmode='group',
+               filename='barcharts',
+               width=None,
+               height=None,
+               log_x=False,
+               log_y=False,
+               create_html=True):
+    """
+    Creates barcharts for numeric data as they compare across categories
+    :param df: pandas dataframe
+    :param col_types: dictionary that contains mapping of column type to list of column names
+                    It is the output of extract_col_types in tabular module
+    :param maximum_number_bars: int, maximum number of bars in all charts
+    :param color: str, column name to color the chart
+    :param orientation: str, the orientation of the figure, 'v' or 'h'
+    :param opacity:
+    :param barmode:
+    :param filename::str, filename for the html file
+    :param width: int, width of chart in pixels
+    :param height: int, height of chart in pixels
+    :return: list which contains plotly graph objects
+    """
+    assert isinstance(df, pd.DataFrame), "df must be a pandas dataframe"
+    assert isinstance(col_types, dict), "col_types must be a dictionary"
+    keys = col_types.keys()
+    assert 'numeric' in keys, "col_types dictionary missing key numeric"
+    assert 'object' in keys, "col_types dictionary missing key object"
+    assert 'boolean' in keys, "col_types dictionary missing key boolean"
+    assert 'categorical' in keys, "col_types dictionary missing key categorical"
+    assert 'datetime' in keys, "col_types dictionary missing key datetime"
+    assert 'timedelta' in keys, "col_types dictionary missing key timedelta"
+    assert isinstance(maximum_number_bars,int), "maximum_number_bars must be an int"
+    combined = list()
+    categorical = col_types['categorical']
+    object_cols = col_types['object']
+    boolean_cols = col_types['boolean']
+    combined.extend(categorical)
+    combined.extend(object_cols)
+    combined.extend(boolean_cols)
+    combined.extend([None])
+    assert color in combined,"color column must be categorical in nature"
+    assert orientation in ['v', 'h'], "orientation must be a string with either v or h"
+    assert opacity <= 1.0, "opacity must be a number between 0 and 1"
+    assert opacity >= 0.0, "opacity must be a number between 0 and 1"
+    assert barmode in ['group', 'overlay', 'relative']
+    assert isinstance(filename, str), "filename must be a string without a dot or an extension"
+    assert '.' not in filename, "filename doesn't need an extension"
+    assert isinstance(width, int) or width is None,"width must be an int or None"
+    assert isinstance(height, int) or height is None,"height must be an int or None"
+    assert isinstance(log_y,bool)
+    assert isinstance(log_x,bool)
+    assert isinstance(create_html,bool)
+
+    figure_list = list()
+    numeric_cols = col_types['numeric']
+
+    categorical_columns = columns_with_distinct_values(df=df,
+                                                       maximum_number_distinct_values=maximum_number_bars)
+
+    if len(numeric_cols) != 0 and len(categorical_columns) != 0:
+        for col in numeric_cols:
+            for category in categorical_columns:
+
+                plot = px.bar(data_frame=df,
+                              x=category,
+                              y=col,
+                              color=color,
+                              opacity=opacity,
+                              orientation=orientation,
+                              barmode=barmode,
+                              log_y=log_y,
+                              log_x=log_x,
+                              width=width,
+                              height=height,
+                              title="Barchart of {} across {} categories".format(col,category)
+                              )
+
+                figure_list.append(plot)
+
+    if create_html:
+
+        figures_to_html(figs=figure_list, filename=filename)
+
+    return figure_list
+
+
+
+
 
 
 
